% Estimator of the Hurst parameter of LRD stationary time series 
% using BIC criterium of 
% following an adaptive procedure of Bhansali Giraitis Kokoszka (2006)
% Call 8 routines: qww1,qww2,qww3,qww4,qww5,qww6,qww7,qww8
%
% Input :	* traj: observation of LRD stationary time series
%
% Output :	* HBGK: estimator of Hurst parameter
%				* b: order obtained from the BIC criterium
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function [HBGK,bb]=BIC_BGK(traj)

global init perfbm d1 d2 lambda nbpoints

perfbm=0;
lambda=0;
prerfbm=0;
nbpoints=length(traj);
nhalfm=fix((nbpoints-1)/2);
lambda=2*pi*(1:nhalfm)/nbpoints;
prerfbm=(abs(fft(traj)).^2)/(2*pi*nbpoints);
perfbm(1:nhalfm)=prerfbm(2:(nhalfm+1));
d=LocWhittleRobinson(traj)-0.5;
init=2*d;
d1=max(init-2/nbpoints^0.25);
d2=min(init+2/nbpoints^0.25,1);

x=0;
F=0;
G=0;
wd=0;
bb=0;fval=0;exitflag=0;
[x,fval,exitflag]=fminsearch('qww1',[init,0.2,0]);
if exitflag<=0.5
    [x,fval,exitflag]=fminsearch('qww1',[init,1,1]);
    if exitflag<=0.5
        [x,fval,exitflag]=fminsearch('qww1',[0,0,1]);
    end
end
F(1)=fval;
wd(1)=x(1);

x=0;fval=0;exitflag=0;
[x,fval,exitflag]=fminsearch('qww2',[init,0.2,0,0]);
if exitflag<=0.5
    [x,fval,exitflag]=fminsearch('qww2',[init,0.2,1,0]);
    if exitflag<=0.5
        [x,fval,exitflag]=fminsearch('qww2',[0,0,1,0]);
    end
    if exitflag<=0.5
        [x,fval,exitflag]=fminsearch('qww2',[0.5,0,0,1]);
    end
 end
F(2)=fval;
wd(2)=x(1);

x=0;fval=0;exitflag=0;
[x,fval,exitflag]=fminsearch('qww3',[init,0.2,0,0,0]);
if exitflag<=0.5
    [x,fval,exitflag]=fminsearch('qww3',[init,0.2,1,0,0]);
    if exitflag<=0.5
        [x,fval,exitflag]=fminsearch('qww3',[0,0,1,0,0]);
    end
    if exitflag<=0.5
        [x,fval,exitflag]=fminsearch('qww3',[0.5,0,0,1,0]);
    end
 end
F(3)=fval;
wd(3)=x(1);

x=0;fval=0;exitflag=0;
[x,fval,exitflag]=fminsearch('qww4',[init,0.2,0,0,0,0]);
if exitflag<=0.5
    [x,fval,exitflag]=fminsearch('qww4',[init,0.2,1,0,0,0]);
    if exitflag<=0.5
        [x,fval,exitflag]=fminsearch('qww4',[0,0,1,0,0,0]);
    end
    if exitflag<=0.5
        [x,fval,exitflag]=fminsearch('qww4',[0.5,0,0,1,0,0]);
    end
 end
F(4)=fval;
wd(4)=x(1);

x=0;fval=0;exitflag=0;
[x,fval,exitflag]=fminsearch('qww5',[init,0.2,0,0,0,0,0]);
if exitflag<=0.5
    [x,fval,exitflag]=fminsearch('qww5',[init,0.2,1,0,0,0,0]);
    if exitflag<=0.5
        [x,fval,exitflag]=fminsearch('qww5',[0,0,1,0,0,0,0]);
    end
    if exitflag<=0.5
        [x,fval,exitflag]=fminsearch('qww5',[0.5,0,0,1,0,0,0]);
    end
 end
F(5)=fval;
wd(5)=x(1);

x=0;fval=0;exitflag=0;
[x,fval,exitflag]=fminsearch('qww6',[init,0.2,0,0,0,0,0,0]);
if exitflag<=0.5
    [x,fval,exitflag]=fminsearch('qww6',[init,0.2,1,0,0,0,0,0]);
    if exitflag<=0.5
        [x,fval,exitflag]=fminsearch('qww6',[0,0,1,0,0,0,0,0]);
    end
    if exitflag<=0.5
        [x,fval,exitflag]=fminsearch('qww6',[0.5,0,0,1,0,0,0,0]);
    end
 end
F(6)=fval;
wd(6)=x(1);

x=0;fval=0;exitflag=0;
[x,fval,exitflag]=fminsearch('qww7',[init,0.2,0,0,0,0,0,0,0]);
if exitflag<=0.5
    [x,fval,exitflag]=fminsearch('qww7',[init,0.2,1,0,0,0,0,0,0]);
    if exitflag<=0.5
        [x,fval,exitflag]=fminsearch('qww7',[0,0,1,0,0,0,0,0,0]);
    end
    if exitflag<=0.5
        [x,fval,exitflag]=fminsearch('qww7',[0.5,0,0,1,0,0,0,0,0]);
    end
 end
F(7)=fval;
wd(7)=x(1);

x=0;fval=0;exitflag=0;
[x,fval,exitflag]=fminsearch('qww8',[init,0.2,0,0,0,0,0,0,0,0]);
if exitflag<=0.5
    [x,fval,exitflag]=fminsearch('qww8',[init,0.2,1,0,0,0,0,0,0,0]);
    if exitflag<=0.5
        [x,fval,exitflag]=fminsearch('qww8',[0,0,1,0,0,0,0,0,0,0]);
    end
    if exitflag<=0.5
        [x,fval,exitflag]=fminsearch('qww8',[0.5,0,0,1,0,0,0,0,0,0]);
    end
 end
F(8)=fval;
wd(8)=x(1);


for b=1:8
     G(b)=F(b)*nbpoints+2*log(nbpoints)*b/nbpoints;
  end
clear init perfbm d1 d2 lambda nbpoints;
bb=find(G==min(G));
HBGK=0.5+wd(bb)/2;
      
